@@ -1,5 +1,5 @@
 """
-This contains the main SceneMark class and its methods for the Scenera Node SDK.
+This filecontains the main SceneMark class and its methods for the Scenera Node SDK.
 """
 
 __author__ = 'Dirk Meulenbelt'
@@ -28,14 +28,12 @@ class SceneMark:
 
     Parameters
     ----------
-    request : incoming request
-        The incoming request including a SceneMark and a NodeSequencerAddress
-    node_id : string
-        Env variable assigned to the Node through the Developer Portal. The Node ID is the unique identifier of the Node.
-    event_type : string
-        Env variable assigned to the Node through the Developer Portal.
-        The main thing this Node is 'interested in'. Can take a range of
-        values from the specification:
+    request : incoming request including a SceneMark and a NodeSequencerAddress
+    node_id : string, env variable assigned to the Node through the Developer Portal.
+        The Node ID is the unique identifier of the Node.
+    event_type : string, env variable assigned to the Node through the Developer Portal.
+        The main thing this Node is 'interested in'. Can take a range of values from
+        the specification:
 
         "Custom",\n
         "ItemPresence",\n
@@ -49,11 +47,11 @@ class SceneMark:
         "Xray",\n
         "Facility"
 
-    analysis_description : string, default None
-        Env variable assigned to the Node through the Developer Portal.
-        Used to describe what the analysis is about, what it is 'doing'.
-    analysis_id : string, default None
-        Env variable assigned to the Node through the Developer Portal.
+    custom_event_type : string, default "", set when the EventType is set to "Custom"
+    analysis_description : string, default "", env variable assigned to the Node
+        through the Developer Portal. Used to describe what the analysis is about,
+        what it is 'doing'. By default set to an empty string.
+    analysis_id : string, default "", env variable assigned to the Node through the Developer Portal.
         Should be a unique identifier refering to the particular algorithm
         used within the node.
     """
@@ -71,7 +69,7 @@ class SceneMark:
         self.scenemark = request.json['SceneMark']
         self.request_json_validator(self.scenemark, SceneMarkSchema)
 
-        # Verify that we get an address to return the SceneMark
+        # Verify that we get an address to return the SceneMark z
         self.nodesequencer_address = request.json['NodeSequencerAddress']
         self.request_json_validator(self.nodesequencer_address, NodesequencerAddressSchema)
 
@@ -93,19 +91,16 @@ class SceneMark:
     def save_request(self, request_type : str, name : str):
         """
         Used for development purposes to manually check the request.
+        Saves the request as a json to file
 
         Parameters
         ----------
         request_type : string
             "SM" for SceneMark,
-            "NS" for NodeSequencer Address
+            "NS" for the NodeSequencer Address
         name : string
             The name you want to save the json as. Defaults to "scenemark" or
             "nodesequencer_address" based on request_type setting
-
-        Returns
-        -------
-        Saved json file of the (state of the) SceneMark or NodeSequencer Address
         """
         assert request_type in ("SM", "NS")
         if request_type == "SM":
@@ -158,6 +153,10 @@ class SceneMark:
         Creates a dictionary that has the datatype as key, and the uri as value,
         like so:
 
+        Returns
+        -------
+        * scenedata_data_type_uri_dict : dict of {datatype -> scenedata_uri}
+
         Example
         -------
         {
@@ -165,10 +164,6 @@ class SceneMark:
             'RGBStill': https://scenedatauri.example.com/1234_still.jpg,
             'RGBVideo': https://scenedatauri.example.com/1234_vid.mp4,
         }
-
-        Returns
-        -------
-        * scenedata_data_type_uri_dict : dict of {datatype -> scenedata_uri}
         """
         return {scenedata_item['DataType']:scenedata_item['SceneDataURI'] \
             for scenedata_item in self.scenemark['SceneDataList']}
@@ -178,6 +173,10 @@ class SceneMark:
         Creates a dictionary that has the datatype as key, and the uri as value,
         like so:
 
+        Returns
+        -------
+        * scenedata_id_uri_dict : dict of {scenedata_id -> scenedata_uri}
+
         Example
         -------
         {
@@ -185,10 +184,6 @@ class SceneMark:
             'SDT_4f2b308f-851a-43ae-819a-0a255dc194a0_dd37_73ac02': https://scenedatauri.example.com/1234_still.jpg,
             'SDT_4f2b308f-851a-43ae-819a-0a255dc194a0_dd37_73ac03': https://scenedatauri.example.com/1234_vid.mp4,
         }
-
-        Returns
-        -------
-        * scenedata_id_uri_dict : dict of {scenedata_id -> scenedata_uri}
         """
         return {scenedata_item['SceneDataID']:scenedata_item['SceneDataURI'] \
             for scenedata_item in self.scenemark['SceneDataList']}
@@ -231,9 +226,9 @@ class SceneMark:
         ----------
         scenedata_uri : string
 
-        Returns
-        -------
-        * SceneDataID, or "No match" if there is no match.
+        Returns / Raises
+        ----------------
+        * SceneDataID, or a Validation Error "No match" if there is no match.
         """
         for scenedata in self.scenemark['SceneDataList']:
             if scenedata['SceneDataURI'] == uri:
@@ -248,9 +243,9 @@ class SceneMark:
         ----------
         scenedata_id : string
 
-        Returns
-        -------
-        * SceneDataURI, or "No match" if there is no match.
+        Returns / Raises
+        ----------------
+        * SceneDataURI, or a Valiation Error "No match" if there is no match.
         """
         for scenedata in self.scenemark['SceneDataList']:
             if scenedata['SceneDataID'] == id:
@@ -367,24 +362,14 @@ class SceneMark:
             indicating the NICEITemType found
         related_scenedata_id : string,
             mandatory indication of what item the algorithm ran on
-        custom_item_type : string,
-            Allows specifying the custom NICEItemType
-            Non-mandatory, defaults to None
-        item_id ; string,
-            Indicating an ID on the object, e.g. the person's name
-            Non-mandatory, defaults to None
-        item_type_count : int,
-            Counting the amount of the stated NICEItemType
-            Non-mandatory, defaults to None
-        probability : float,
-            Indicating the confidence on the item
-            Non-mandatory, defaults to None
-        attributes : list,
-            Containing attribute items
-            Non-mandatory, defaults to None
-        bounding_box : dictionary,
-            Containing the bounding box
-            Non-mandatory, defaults to None
+        custom_item_type : string, default "", allows specifying the custom
+            NICEItemType
+        item_id ; string, default "", indicating an ID on the object, e.g.
+            the person's name
+        item_type_count : int, default 1, counting the amount of the stated NICEItemType
+        probability : float, default 1.0, indicating the confidence on the item
+        attributes : list, default [], containing attribute items
+        bounding_box : dictionary, default {}, containing the bounding box
 
         Returns
         -------
@@ -454,17 +439,17 @@ class SceneMark:
             "Undetected",\n
             "Failed",\n
             "Error"
-        custom_event_type : string, set if the above processing status
+        custom_event_type : string, default "", set if the above processing status
             equals CustomAnalysis
-        total_item_count : int, total amount of items detected in the scene
-        error_message : string, used to propagate errors
-        detected_objects : list of objects, generated
+        total_item_count : int, default 0, total amount of items detected in the scene
+        error_message : string, default "", used to propagate errors
+        detected_objects : list, default [], of objects, generated
         event_type : string, set internally by the initialization of the scenemark
             object, but may be changed for custom purposes
 
         Example:
         --------
-       {
+        {
             "VersionNumber": 1.0,
             "AnalysisID": "9cdff73f-5db1-4e64-9656-ef83bdfeeb90",
             "AnalysisDescription": "Loitering detection",
@@ -503,26 +488,25 @@ class SceneMark:
 
     def add_thumbnail_list_item(self, scenedata_id : str):
         """
-        Gets the SceneDataURI of the SceneDataID you put in.
-
-        Example:
-        --------
-        {
-            'SDT_4f2b308f-851a-43ae-819a-0a255dc194a0_dd37_73ac01':
-                            https://scenedatauri.example.com/1234_thumb.jpg,
-            'SDT_4f2b308f-851a-43ae-819a-0a255dc194a0_dd37_73ac02':
-                            https://scenedatauri.example.com/1234_still.jpg,
-            'SDT_4f2b308f-851a-43ae-819a-0a255dc194a0_dd37_73ac03':
-                            https://scenedatauri.example.com/1234_vid.mp4,
-        }
+        Adds a new thumbnail list item to the thumbnail list in the SceneMark
+        Use this method when you want to instruct the app to use a different
+        image as the thumbnail to be displayed.
 
         Parameters
         ----------
         scenedata_id : string
 
-        Returns
+        Note
+        ----
+        Use the Thumbnail id of any existing SceneData, such as a SceneData item
+        that you have added yourself.
+
+        Example
         -------
-        * SceneDataURI, or "No match" if there is no match.
+        {
+            "VersionNumber": 1.0,
+            "SceneDataID": "SDT_83d6a043-00d9-49aa-a295-86a041fff6d8_d3e7_8a7d01"
+        }
         """
         thumbnail_list_item = {}
         thumbnail_list_item['VersionNumber'] = self.my_version_number
@@ -542,26 +526,39 @@ class SceneMark:
         embedded_scenedata : str = "",
         ):
         """
-        Gets the SceneDataURI of the SceneDataID you put in.
+        Adds a SceneData item to the SceneMark
 
-        Example:
-        --------
+        Example
+        -------
         {
-            'SDT_4f2b308f-851a-43ae-819a-0a255dc194a0_dd37_73ac01':
-                            https://scenedatauri.example.com/1234_thumb.jpg,
-            'SDT_4f2b308f-851a-43ae-819a-0a255dc194a0_dd37_73ac02':
-                            https://scenedatauri.example.com/1234_still.jpg,
-            'SDT_4f2b308f-851a-43ae-819a-0a255dc194a0_dd37_73ac03':
-                            https://scenedatauri.example.com/1234_vid.mp4,
+            "VersionNumber": 2.0,
+            "SceneDataID": "SDT_83d6a043-00d9-49aa-a295-86a041fff6d8_d3e7_123456",
+            "TimeStamp": "2021-10-29T21:12:17.245Z",
+            "SourceNodeID": "83d6a043-00d9-49aa-a295-86a041fff6d8_d3e7",
+            "SourceNodeDescription": "Scenera Bridge",
+            "Duration": "30",
+            "DataType": "RGBVideo",
+            "Status": "Upload in Progress",
+            "MediaFormat": "H.264",
+            "SceneDataURI": "https://sduri.example.com/vid.mp4",
+            "Resolution": {
+                "Height": 100,
+                "Width": 100
+            },
+            "EmbeddedSceneData": None,
+            "Encryption": False
         }
 
         Parameters
         ----------
-        scenedata_id : string
-
-        Returns
-        -------
-        * SceneDataURI, or "No match" if there is no match.
+        scenedata_uri : string, the uri where the
+        datatype : str,
+        source_node_description : str = "",
+        timestamp : str = "",
+        duration : str  = "",
+        media_format : str = "",
+        encryption : bool = False,
+        embedded_scenedata : str = "",
         """
 
         scenedata_list_item = {}
@@ -605,23 +602,16 @@ class SceneMark:
 
     def add_version_control_item(self):
         """
-        Gets the SceneDataURI of the SceneDataID you put in.
+        Adds a Version Control item to the SceneMark. Uses already existing
+        data and is called automatically by the __init__ method
 
         Example:
         --------
         {
-            'SDT_4f2b308f-851a-43ae-819a-0a255dc194a0_dd37_73ac01': https://scenedatauri.example.com/1234_thumb.jpg,
-            'SDT_4f2b308f-851a-43ae-819a-0a255dc194a0_dd37_73ac02': https://scenedatauri.example.com/1234_still.jpg,
-            'SDT_4f2b308f-851a-43ae-819a-0a255dc194a0_dd37_73ac03': https://scenedatauri.example.com/1234_vid.mp4,
+            "VersionNumber": 2.0,
+            "DateTimeStamp": "2021-07-19T16:25:21.647Z",
+            "NodeID": "NodeID"
         }
-
-        Parameters
-        ----------
-        scenedata_id : string
-
-        Returns
-        -------
-        * SceneDataURI, or "No match" if there is no match.
         """
         version_list_item = {}
         version_list_item['VersionNumber'] = self.my_version_number
@@ -630,25 +620,19 @@ class SceneMark:
 
         self.scenemark['VersionControl']['VersionList'].append(version_list_item)
 
-    def return_scenemark_to_ns(self, test):
+    def return_scenemark_to_ns(self, test = False):
         """
-        Gets the SceneDataURI of the SceneDataID you put in.
-
-        Example:
-        --------
-        {
-            'SDT_4f2b308f-851a-43ae-819a-0a255dc194a0_dd37_73ac01': https://scenedatauri.example.com/1234_thumb.jpg,
-            'SDT_4f2b308f-851a-43ae-819a-0a255dc194a0_dd37_73ac02': https://scenedatauri.example.com/1234_still.jpg,
-            'SDT_4f2b308f-851a-43ae-819a-0a255dc194a0_dd37_73ac03': https://scenedatauri.example.com/1234_vid.mp4,
-        }
+        Returns the SceneMark to the NodeSequencer using the received address
 
         Parameters
         ----------
-        scenedata_id : string
+        test : bool, default False, if set to True this returns the scenemark
+            straight to the caller so you can test the node from Postman or
+            some other app
 
         Returns
         -------
-        * SceneDataURI, or "No match" if there is no match.
+        * SceneMark
         """
 
         # Update our original request with the updated SceneMark
@@ -672,7 +656,7 @@ class SceneMark:
             stream=False)
         print("Returning to Node Sequencer", answer)
 
-        # Helper Functions
+    # Helper Functions
     def get_current_utc_timestamp(self):
         return f"{'{:%Y-%m-%dT%H:%M:%S.%f}'.format(datetime.datetime.utcnow())[:-3]}Z"
 
